# coding: utf-8

"""
    workflow.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from core.api.api_client import ApiClient
from core.api.exceptions import (
    ApiTypeError,
    ApiValueError
)


class SecretServiceApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_secret_key_value(self, namespace, secret_name, body, **kwargs):  # noqa: E501
        """add_secret_key_value  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_secret_key_value(namespace, secret_name, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str secret_name: (required)
        :param Secret body: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AddSecretKeyValueResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.add_secret_key_value_with_http_info(namespace, secret_name, body, **kwargs)  # noqa: E501

    def add_secret_key_value_with_http_info(self, namespace, secret_name, body, **kwargs):  # noqa: E501
        """add_secret_key_value  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_secret_key_value_with_http_info(namespace, secret_name, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str secret_name: (required)
        :param Secret body: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AddSecretKeyValueResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace', 'secret_name', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_secret_key_value" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if self.api_client.client_side_validation and ('namespace' not in local_var_params or  # noqa: E501
                                                        local_var_params['namespace'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `namespace` when calling `add_secret_key_value`")  # noqa: E501
        # verify the required parameter 'secret_name' is set
        if self.api_client.client_side_validation and ('secret_name' not in local_var_params or  # noqa: E501
                                                        local_var_params['secret_name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `secret_name` when calling `add_secret_key_value`")  # noqa: E501
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in local_var_params or  # noqa: E501
                                                        local_var_params['body'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `body` when calling `add_secret_key_value`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'secret_name' in local_var_params:
            path_params['secret.name'] = local_var_params['secret_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/apis/v1beta1/{namespace}/secrets/{secret.name}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AddSecretKeyValueResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_secret(self, namespace, body, **kwargs):  # noqa: E501
        """create_secret  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_secret(namespace, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param Secret body: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_secret_with_http_info(namespace, body, **kwargs)  # noqa: E501

    def create_secret_with_http_info(self, namespace, body, **kwargs):  # noqa: E501
        """create_secret  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_secret_with_http_info(namespace, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param Secret body: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_secret" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if self.api_client.client_side_validation and ('namespace' not in local_var_params or  # noqa: E501
                                                        local_var_params['namespace'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `namespace` when calling `create_secret`")  # noqa: E501
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in local_var_params or  # noqa: E501
                                                        local_var_params['body'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `body` when calling `create_secret`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/apis/v1beta1/{namespace}/secrets', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_secret(self, namespace, name, **kwargs):  # noqa: E501
        """delete_secret  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_secret(namespace, name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str name: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DeleteSecretResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_secret_with_http_info(namespace, name, **kwargs)  # noqa: E501

    def delete_secret_with_http_info(self, namespace, name, **kwargs):  # noqa: E501
        """delete_secret  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_secret_with_http_info(namespace, name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str name: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DeleteSecretResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace', 'name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_secret" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if self.api_client.client_side_validation and ('namespace' not in local_var_params or  # noqa: E501
                                                        local_var_params['namespace'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `namespace` when calling `delete_secret`")  # noqa: E501
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in local_var_params or  # noqa: E501
                                                        local_var_params['name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `name` when calling `delete_secret`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'name' in local_var_params:
            path_params['name'] = local_var_params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/apis/v1beta1/{namespace}/secrets/{name}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteSecretResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_secret_key(self, namespace, secret_name, key, **kwargs):  # noqa: E501
        """delete_secret_key  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_secret_key(namespace, secret_name, key, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str secret_name: (required)
        :param str key: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DeleteSecretKeyResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_secret_key_with_http_info(namespace, secret_name, key, **kwargs)  # noqa: E501

    def delete_secret_key_with_http_info(self, namespace, secret_name, key, **kwargs):  # noqa: E501
        """delete_secret_key  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_secret_key_with_http_info(namespace, secret_name, key, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str secret_name: (required)
        :param str key: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DeleteSecretKeyResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace', 'secret_name', 'key']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_secret_key" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if self.api_client.client_side_validation and ('namespace' not in local_var_params or  # noqa: E501
                                                        local_var_params['namespace'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `namespace` when calling `delete_secret_key`")  # noqa: E501
        # verify the required parameter 'secret_name' is set
        if self.api_client.client_side_validation and ('secret_name' not in local_var_params or  # noqa: E501
                                                        local_var_params['secret_name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `secret_name` when calling `delete_secret_key`")  # noqa: E501
        # verify the required parameter 'key' is set
        if self.api_client.client_side_validation and ('key' not in local_var_params or  # noqa: E501
                                                        local_var_params['key'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `key` when calling `delete_secret_key`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'secret_name' in local_var_params:
            path_params['secretName'] = local_var_params['secret_name']  # noqa: E501
        if 'key' in local_var_params:
            path_params['key'] = local_var_params['key']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/apis/v1beta1/{namespace}/secrets/{secretName}/keys/{key}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteSecretKeyResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_secret(self, namespace, name, **kwargs):  # noqa: E501
        """get_secret  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_secret(namespace, name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str name: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Secret
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_secret_with_http_info(namespace, name, **kwargs)  # noqa: E501

    def get_secret_with_http_info(self, namespace, name, **kwargs):  # noqa: E501
        """get_secret  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_secret_with_http_info(namespace, name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str name: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Secret, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace', 'name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_secret" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if self.api_client.client_side_validation and ('namespace' not in local_var_params or  # noqa: E501
                                                        local_var_params['namespace'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `namespace` when calling `get_secret`")  # noqa: E501
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in local_var_params or  # noqa: E501
                                                        local_var_params['name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `name` when calling `get_secret`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'name' in local_var_params:
            path_params['name'] = local_var_params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/apis/v1beta1/{namespace}/secrets/{name}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Secret',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_secrets(self, namespace, **kwargs):  # noqa: E501
        """list_secrets  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_secrets(namespace, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ListSecretsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.list_secrets_with_http_info(namespace, **kwargs)  # noqa: E501

    def list_secrets_with_http_info(self, namespace, **kwargs):  # noqa: E501
        """list_secrets  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_secrets_with_http_info(namespace, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ListSecretsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_secrets" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if self.api_client.client_side_validation and ('namespace' not in local_var_params or  # noqa: E501
                                                        local_var_params['namespace'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `namespace` when calling `list_secrets`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/apis/v1beta1/{namespace}/secrets', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListSecretsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def secret_exists(self, namespace, name, **kwargs):  # noqa: E501
        """secret_exists  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.secret_exists(namespace, name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str name: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SecretExistsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.secret_exists_with_http_info(namespace, name, **kwargs)  # noqa: E501

    def secret_exists_with_http_info(self, namespace, name, **kwargs):  # noqa: E501
        """secret_exists  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.secret_exists_with_http_info(namespace, name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str name: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SecretExistsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace', 'name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method secret_exists" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if self.api_client.client_side_validation and ('namespace' not in local_var_params or  # noqa: E501
                                                        local_var_params['namespace'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `namespace` when calling `secret_exists`")  # noqa: E501
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in local_var_params or  # noqa: E501
                                                        local_var_params['name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `name` when calling `secret_exists`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'name' in local_var_params:
            path_params['name'] = local_var_params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/apis/v1beta1/{namespace}/secrets/{name}/exists', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SecretExistsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_secret_key_value(self, namespace, secret_name, body, **kwargs):  # noqa: E501
        """update_secret_key_value  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_secret_key_value(namespace, secret_name, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str secret_name: (required)
        :param Secret body: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: UpdateSecretKeyValueResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_secret_key_value_with_http_info(namespace, secret_name, body, **kwargs)  # noqa: E501

    def update_secret_key_value_with_http_info(self, namespace, secret_name, body, **kwargs):  # noqa: E501
        """update_secret_key_value  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_secret_key_value_with_http_info(namespace, secret_name, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str secret_name: (required)
        :param Secret body: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(UpdateSecretKeyValueResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace', 'secret_name', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_secret_key_value" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if self.api_client.client_side_validation and ('namespace' not in local_var_params or  # noqa: E501
                                                        local_var_params['namespace'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `namespace` when calling `update_secret_key_value`")  # noqa: E501
        # verify the required parameter 'secret_name' is set
        if self.api_client.client_side_validation and ('secret_name' not in local_var_params or  # noqa: E501
                                                        local_var_params['secret_name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `secret_name` when calling `update_secret_key_value`")  # noqa: E501
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in local_var_params or  # noqa: E501
                                                        local_var_params['body'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `body` when calling `update_secret_key_value`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'secret_name' in local_var_params:
            path_params['secret.name'] = local_var_params['secret_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/apis/v1beta1/{namespace}/secrets/{secret.name}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UpdateSecretKeyValueResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Onepanel

    Onepanel API  # noqa: E501

    The version of the OpenAPI document: 0.12.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import onepanel.core.api
from onepanel.core.api.api.workspace_template_service_api import WorkspaceTemplateServiceApi  # noqa: E501
from onepanel.core.api.rest import ApiException


class TestWorkspaceTemplateServiceApi(unittest.TestCase):
    """WorkspaceTemplateServiceApi unit test stubs"""

    def setUp(self):
        self.api = onepanel.core.api.api.workspace_template_service_api.WorkspaceTemplateServiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_archive_workspace_template(self):
        """Test case for archive_workspace_template

        """
        pass

    def test_create_workspace_template(self):
        """Test case for create_workspace_template

        """
        pass

    def test_generate_workspace_template_workflow_template(self):
        """Test case for generate_workspace_template_workflow_template

        """
        pass

    def test_get_workspace_template(self):
        """Test case for get_workspace_template

        """
        pass

    def test_list_workspace_template_versions(self):
        """Test case for list_workspace_template_versions

        """
        pass

    def test_list_workspace_templates(self):
        """Test case for list_workspace_templates

        """
        pass

    def test_update_workspace_template(self):
        """Test case for update_workspace_template

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Onepanel

    Onepanel API  # noqa: E501

    The version of the OpenAPI document: 0.12.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "0.12.0b2"

# import apis into sdk package
from onepanel.core.api.api.auth_service_api import AuthServiceApi
from onepanel.core.api.api.config_service_api import ConfigServiceApi
from onepanel.core.api.api.cron_workflow_service_api import CronWorkflowServiceApi
from onepanel.core.api.api.label_service_api import LabelServiceApi
from onepanel.core.api.api.namespace_service_api import NamespaceServiceApi
from onepanel.core.api.api.secret_service_api import SecretServiceApi
from onepanel.core.api.api.service_service_api import ServiceServiceApi
from onepanel.core.api.api.workflow_service_api import WorkflowServiceApi
from onepanel.core.api.api.workflow_template_service_api import WorkflowTemplateServiceApi
from onepanel.core.api.api.workspace_service_api import WorkspaceServiceApi
from onepanel.core.api.api.workspace_template_service_api import WorkspaceTemplateServiceApi

# import ApiClient
from onepanel.core.api.api_client import ApiClient
from onepanel.core.api.configuration import Configuration
from onepanel.core.api.exceptions import OpenApiException
from onepanel.core.api.exceptions import ApiTypeError
from onepanel.core.api.exceptions import ApiValueError
from onepanel.core.api.exceptions import ApiKeyError
from onepanel.core.api.exceptions import ApiAttributeError
from onepanel.core.api.exceptions import ApiException
# import models into sdk package
from onepanel.core.api.models.add_secret_key_value_response import AddSecretKeyValueResponse
from onepanel.core.api.models.archive_workflow_template_response import ArchiveWorkflowTemplateResponse
from onepanel.core.api.models.artifact_response import ArtifactResponse
from onepanel.core.api.models.create_workflow_execution_body import CreateWorkflowExecutionBody
from onepanel.core.api.models.create_workspace_body import CreateWorkspaceBody
from onepanel.core.api.models.cron_workflow import CronWorkflow
from onepanel.core.api.models.cron_workflow_statistics_report import CronWorkflowStatisticsReport
from onepanel.core.api.models.delete_secret_key_response import DeleteSecretKeyResponse
from onepanel.core.api.models.delete_secret_response import DeleteSecretResponse
from onepanel.core.api.models.file import File
from onepanel.core.api.models.get_config_response import GetConfigResponse
from onepanel.core.api.models.get_labels_response import GetLabelsResponse
from onepanel.core.api.models.get_workflow_execution_metrics_response import GetWorkflowExecutionMetricsResponse
from onepanel.core.api.models.google_protobuf_any import GoogleProtobufAny
from onepanel.core.api.models.grpc_gateway_runtime_error import GrpcGatewayRuntimeError
from onepanel.core.api.models.grpc_gateway_runtime_stream_error import GrpcGatewayRuntimeStreamError
from onepanel.core.api.models.is_authorized import IsAuthorized
from onepanel.core.api.models.is_authorized_response import IsAuthorizedResponse
from onepanel.core.api.models.is_valid_token_response import IsValidTokenResponse
from onepanel.core.api.models.key_value import KeyValue
from onepanel.core.api.models.labels import Labels
from onepanel.core.api.models.list_cron_workflows_response import ListCronWorkflowsResponse
from onepanel.core.api.models.list_files_response import ListFilesResponse
from onepanel.core.api.models.list_namespaces_response import ListNamespacesResponse
from onepanel.core.api.models.list_secrets_response import ListSecretsResponse
from onepanel.core.api.models.list_services_response import ListServicesResponse
from onepanel.core.api.models.list_workflow_executions_response import ListWorkflowExecutionsResponse
from onepanel.core.api.models.list_workflow_template_versions_response import ListWorkflowTemplateVersionsResponse
from onepanel.core.api.models.list_workflow_templates_response import ListWorkflowTemplatesResponse
from onepanel.core.api.models.list_workspace_response import ListWorkspaceResponse
from onepanel.core.api.models.list_workspace_template_versions_response import ListWorkspaceTemplateVersionsResponse
from onepanel.core.api.models.list_workspace_templates_response import ListWorkspaceTemplatesResponse
from onepanel.core.api.models.log_entry import LogEntry
from onepanel.core.api.models.metric import Metric
from onepanel.core.api.models.namespace import Namespace
from onepanel.core.api.models.node_pool import NodePool
from onepanel.core.api.models.node_pool_option import NodePoolOption
from onepanel.core.api.models.parameter import Parameter
from onepanel.core.api.models.parameter_option import ParameterOption
from onepanel.core.api.models.secret import Secret
from onepanel.core.api.models.secret_exists_response import SecretExistsResponse
from onepanel.core.api.models.service import Service
from onepanel.core.api.models.statistics import Statistics
from onepanel.core.api.models.stream_result_of_log_entry import StreamResultOfLogEntry
from onepanel.core.api.models.stream_result_of_workflow_execution import StreamResultOfWorkflowExecution
from onepanel.core.api.models.token_wrapper import TokenWrapper
from onepanel.core.api.models.update_secret_key_value_response import UpdateSecretKeyValueResponse
from onepanel.core.api.models.update_workspace_body import UpdateWorkspaceBody
from onepanel.core.api.models.workflow_execution import WorkflowExecution
from onepanel.core.api.models.workflow_execution_metadata import WorkflowExecutionMetadata
from onepanel.core.api.models.workflow_execution_statistic_report import WorkflowExecutionStatisticReport
from onepanel.core.api.models.workflow_execution_status import WorkflowExecutionStatus
from onepanel.core.api.models.workflow_template import WorkflowTemplate
from onepanel.core.api.models.workspace import Workspace
from onepanel.core.api.models.workspace_status import WorkspaceStatus
from onepanel.core.api.models.workspace_template import WorkspaceTemplate




from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from core.api.api.namespace_service_api import NamespaceServiceApi
from core.api.api.secret_service_api import SecretServiceApi
from core.api.api.workflow_service_api import WorkflowServiceApi



# coding: utf-8

"""
    Onepanel

    Onepanel API  # noqa: E501

    The version of the OpenAPI document: 0.12.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onepanel.core.api
from onepanel.core.api.models.archive_workflow_template_response import ArchiveWorkflowTemplateResponse  # noqa: E501
from onepanel.core.api.rest import ApiException

class TestArchiveWorkflowTemplateResponse(unittest.TestCase):
    """ArchiveWorkflowTemplateResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ArchiveWorkflowTemplateResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = onepanel.core.api.models.archive_workflow_template_response.ArchiveWorkflowTemplateResponse()  # noqa: E501
        if include_optional :
            return ArchiveWorkflowTemplateResponse(
                workflow_template = onepanel.core.api.models.workflow_template.WorkflowTemplate(
                    created_at = '0', 
                    modified_at = '0', 
                    uid = '0', 
                    name = '0', 
                    version = '0', 
                    versions = '0', 
                    manifest = '0', 
                    is_latest = True, 
                    is_archived = True, 
                    labels = [
                        onepanel.core.api.models.key_value.KeyValue(
                            key = '0', 
                            value = '0', )
                        ], 
                    stats = onepanel.core.api.models.workflow_execution_statistic_report.WorkflowExecutionStatisticReport(
                        total = 56, 
                        last_executed = '0', 
                        running = 56, 
                        completed = 56, 
                        failed = 56, 
                        terminated = 56, ), 
                    cron_stats = onepanel.core.api.models.cron_workflow_statistics_report.CronWorkflowStatisticsReport(
                        total = 56, ), )
            )
        else :
            return ArchiveWorkflowTemplateResponse(
        )

    def testArchiveWorkflowTemplateResponse(self):
        """Test ArchiveWorkflowTemplateResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Onepanel

    Onepanel API  # noqa: E501

    The version of the OpenAPI document: 0.12.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onepanel.core.api
from onepanel.core.api.models.list_workflow_templates_response import ListWorkflowTemplatesResponse  # noqa: E501
from onepanel.core.api.rest import ApiException

class TestListWorkflowTemplatesResponse(unittest.TestCase):
    """ListWorkflowTemplatesResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListWorkflowTemplatesResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = onepanel.core.api.models.list_workflow_templates_response.ListWorkflowTemplatesResponse()  # noqa: E501
        if include_optional :
            return ListWorkflowTemplatesResponse(
                count = 56, 
                workflow_templates = [
                    onepanel.core.api.models.workflow_template.WorkflowTemplate(
                        created_at = '0', 
                        modified_at = '0', 
                        uid = '0', 
                        name = '0', 
                        version = '0', 
                        versions = '0', 
                        manifest = '0', 
                        is_latest = True, 
                        is_archived = True, 
                        labels = [
                            onepanel.core.api.models.key_value.KeyValue(
                                key = '0', 
                                value = '0', )
                            ], 
                        stats = onepanel.core.api.models.workflow_execution_statistic_report.WorkflowExecutionStatisticReport(
                            total = 56, 
                            last_executed = '0', 
                            running = 56, 
                            completed = 56, 
                            failed = 56, 
                            terminated = 56, ), 
                        cron_stats = onepanel.core.api.models.cron_workflow_statistics_report.CronWorkflowStatisticsReport(
                            total = 56, ), )
                    ], 
                page = 56, 
                pages = 56, 
                total_count = 56
            )
        else :
            return ListWorkflowTemplatesResponse(
        )

    def testListWorkflowTemplatesResponse(self):
        """Test ListWorkflowTemplatesResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Onepanel

    Onepanel API  # noqa: E501

    The version of the OpenAPI document: 0.12.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import onepanel.core.api
from onepanel.core.api.api.workflow_template_service_api import WorkflowTemplateServiceApi  # noqa: E501
from onepanel.core.api.rest import ApiException


class TestWorkflowTemplateServiceApi(unittest.TestCase):
    """WorkflowTemplateServiceApi unit test stubs"""

    def setUp(self):
        self.api = onepanel.core.api.api.workflow_template_service_api.WorkflowTemplateServiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_archive_workflow_template(self):
        """Test case for archive_workflow_template

        """
        pass

    def test_clone_workflow_template(self):
        """Test case for clone_workflow_template

        """
        pass

    def test_clone_workflow_template2(self):
        """Test case for clone_workflow_template2

        """
        pass

    def test_create_workflow_template(self):
        """Test case for create_workflow_template

        """
        pass

    def test_create_workflow_template_version(self):
        """Test case for create_workflow_template_version

        """
        pass

    def test_get_workflow_template(self):
        """Test case for get_workflow_template

        """
        pass

    def test_get_workflow_template2(self):
        """Test case for get_workflow_template2

        """
        pass

    def test_list_workflow_template_versions(self):
        """Test case for list_workflow_template_versions

        """
        pass

    def test_list_workflow_templates(self):
        """Test case for list_workflow_templates

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Onepanel

    Onepanel API  # noqa: E501

    The version of the OpenAPI document: 0.12.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import onepanel.core.api
from onepanel.core.api.api.workflow_service_api import WorkflowServiceApi  # noqa: E501
from onepanel.core.api.rest import ApiException


class TestWorkflowServiceApi(unittest.TestCase):
    """WorkflowServiceApi unit test stubs"""

    def setUp(self):
        self.api = onepanel.core.api.api.workflow_service_api.WorkflowServiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_workflow_execution_statistics(self):
        """Test case for add_workflow_execution_statistics

        """
        pass

    def test_clone_workflow_execution(self):
        """Test case for clone_workflow_execution

        """
        pass

    def test_create_workflow_execution(self):
        """Test case for create_workflow_execution

        """
        pass

    def test_cron_start_workflow_execution_statistic(self):
        """Test case for cron_start_workflow_execution_statistic

        """
        pass

    def test_get_artifact(self):
        """Test case for get_artifact

        """
        pass

    def test_get_workflow_execution(self):
        """Test case for get_workflow_execution

        """
        pass

    def test_get_workflow_execution_logs(self):
        """Test case for get_workflow_execution_logs

        """
        pass

    def test_get_workflow_execution_metrics(self):
        """Test case for get_workflow_execution_metrics

        """
        pass

    def test_list_files(self):
        """Test case for list_files

        """
        pass

    def test_list_workflow_executions(self):
        """Test case for list_workflow_executions

        """
        pass

    def test_resubmit_workflow_execution(self):
        """Test case for resubmit_workflow_execution

        """
        pass

    def test_terminate_workflow_execution(self):
        """Test case for terminate_workflow_execution

        """
        pass

    def test_update_workflow_execution_status(self):
        """Test case for update_workflow_execution_status

        """
        pass

    def test_watch_workflow_execution(self):
        """Test case for watch_workflow_execution

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Onepanel

    Onepanel API  # noqa: E501

    The version of the OpenAPI document: 0.12.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import onepanel.core.api
from onepanel.core.api.api.secret_service_api import SecretServiceApi  # noqa: E501
from onepanel.core.api.rest import ApiException


class TestSecretServiceApi(unittest.TestCase):
    """SecretServiceApi unit test stubs"""

    def setUp(self):
        self.api = onepanel.core.api.api.secret_service_api.SecretServiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_secret_key_value(self):
        """Test case for add_secret_key_value

        """
        pass

    def test_create_secret(self):
        """Test case for create_secret

        """
        pass

    def test_delete_secret(self):
        """Test case for delete_secret

        """
        pass

    def test_delete_secret_key(self):
        """Test case for delete_secret_key

        """
        pass

    def test_get_secret(self):
        """Test case for get_secret

        """
        pass

    def test_list_secrets(self):
        """Test case for list_secrets

        """
        pass

    def test_secret_exists(self):
        """Test case for secret_exists

        """
        pass

    def test_update_secret_key_value(self):
        """Test case for update_secret_key_value

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Onepanel

    Onepanel API  # noqa: E501

    The version of the OpenAPI document: 0.12.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from onepanel.core.api.configuration import Configuration


class Workspace(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'uid': 'str',
        'name': 'str',
        'version': 'str',
        'created_at': 'str',
        'parameters': 'list[Parameter]',
        'workspace_template': 'WorkspaceTemplate',
        'status': 'WorkspaceStatus',
        'labels': 'list[KeyValue]',
        'url': 'str',
        'template_parameters': 'list[Parameter]'
    }

    attribute_map = {
        'uid': 'uid',
        'name': 'name',
        'version': 'version',
        'created_at': 'createdAt',
        'parameters': 'parameters',
        'workspace_template': 'workspaceTemplate',
        'status': 'status',
        'labels': 'labels',
        'url': 'url',
        'template_parameters': 'templateParameters'
    }

    def __init__(self, uid=None, name=None, version=None, created_at=None, parameters=None, workspace_template=None, status=None, labels=None, url=None, template_parameters=None, local_vars_configuration=None):  # noqa: E501
        """Workspace - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._uid = None
        self._name = None
        self._version = None
        self._created_at = None
        self._parameters = None
        self._workspace_template = None
        self._status = None
        self._labels = None
        self._url = None
        self._template_parameters = None
        self.discriminator = None

        if uid is not None:
            self.uid = uid
        if name is not None:
            self.name = name
        if version is not None:
            self.version = version
        if created_at is not None:
            self.created_at = created_at
        if parameters is not None:
            self.parameters = parameters
        if workspace_template is not None:
            self.workspace_template = workspace_template
        if status is not None:
            self.status = status
        if labels is not None:
            self.labels = labels
        if url is not None:
            self.url = url
        if template_parameters is not None:
            self.template_parameters = template_parameters

    @property
    def uid(self):
        """Gets the uid of this Workspace.  # noqa: E501


        :return: The uid of this Workspace.  # noqa: E501
        :rtype: str
        """
        return self._uid

    @uid.setter
    def uid(self, uid):
        """Sets the uid of this Workspace.


        :param uid: The uid of this Workspace.  # noqa: E501
        :type uid: str
        """

        self._uid = uid

    @property
    def name(self):
        """Gets the name of this Workspace.  # noqa: E501


        :return: The name of this Workspace.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Workspace.


        :param name: The name of this Workspace.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def version(self):
        """Gets the version of this Workspace.  # noqa: E501


        :return: The version of this Workspace.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Workspace.


        :param version: The version of this Workspace.  # noqa: E501
        :type version: str
        """

        self._version = version

    @property
    def created_at(self):
        """Gets the created_at of this Workspace.  # noqa: E501


        :return: The created_at of this Workspace.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Workspace.


        :param created_at: The created_at of this Workspace.  # noqa: E501
        :type created_at: str
        """

        self._created_at = created_at

    @property
    def parameters(self):
        """Gets the parameters of this Workspace.  # noqa: E501


        :return: The parameters of this Workspace.  # noqa: E501
        :rtype: list[Parameter]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this Workspace.


        :param parameters: The parameters of this Workspace.  # noqa: E501
        :type parameters: list[Parameter]
        """

        self._parameters = parameters

    @property
    def workspace_template(self):
        """Gets the workspace_template of this Workspace.  # noqa: E501


        :return: The workspace_template of this Workspace.  # noqa: E501
        :rtype: WorkspaceTemplate
        """
        return self._workspace_template

    @workspace_template.setter
    def workspace_template(self, workspace_template):
        """Sets the workspace_template of this Workspace.


        :param workspace_template: The workspace_template of this Workspace.  # noqa: E501
        :type workspace_template: WorkspaceTemplate
        """

        self._workspace_template = workspace_template

    @property
    def status(self):
        """Gets the status of this Workspace.  # noqa: E501


        :return: The status of this Workspace.  # noqa: E501
        :rtype: WorkspaceStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Workspace.


        :param status: The status of this Workspace.  # noqa: E501
        :type status: WorkspaceStatus
        """

        self._status = status

    @property
    def labels(self):
        """Gets the labels of this Workspace.  # noqa: E501


        :return: The labels of this Workspace.  # noqa: E501
        :rtype: list[KeyValue]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this Workspace.


        :param labels: The labels of this Workspace.  # noqa: E501
        :type labels: list[KeyValue]
        """

        self._labels = labels

    @property
    def url(self):
        """Gets the url of this Workspace.  # noqa: E501


        :return: The url of this Workspace.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this Workspace.


        :param url: The url of this Workspace.  # noqa: E501
        :type url: str
        """

        self._url = url

    @property
    def template_parameters(self):
        """Gets the template_parameters of this Workspace.  # noqa: E501


        :return: The template_parameters of this Workspace.  # noqa: E501
        :rtype: list[Parameter]
        """
        return self._template_parameters

    @template_parameters.setter
    def template_parameters(self, template_parameters):
        """Sets the template_parameters of this Workspace.


        :param template_parameters: The template_parameters of this Workspace.  # noqa: E501
        :type template_parameters: list[Parameter]
        """

        self._template_parameters = template_parameters

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Workspace):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Workspace):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Onepanel

    Onepanel API  # noqa: E501

    The version of the OpenAPI document: 0.12.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onepanel.core.api
from onepanel.core.api.models.list_cron_workflows_response import ListCronWorkflowsResponse  # noqa: E501
from onepanel.core.api.rest import ApiException

class TestListCronWorkflowsResponse(unittest.TestCase):
    """ListCronWorkflowsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListCronWorkflowsResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = onepanel.core.api.models.list_cron_workflows_response.ListCronWorkflowsResponse()  # noqa: E501
        if include_optional :
            return ListCronWorkflowsResponse(
                count = 56, 
                cron_workflows = [
                    onepanel.core.api.models.cron_workflow.CronWorkflow(
                        name = '0', 
                        uid = '0', 
                        manifest = '0', 
                        workflow_execution = onepanel.core.api.models.workflow_execution.WorkflowExecution(
                            created_at = '0', 
                            uid = '0', 
                            name = '0', 
                            phase = '0', 
                            started_at = '0', 
                            finished_at = '0', 
                            manifest = '0', 
                            parameters = [
                                onepanel.core.api.models.parameter.Parameter(
                                    name = '0', 
                                    value = '0', 
                                    type = '0', 
                                    display_name = '0', 
                                    hint = '0', 
                                    required = True, 
                                    options = [
                                        onepanel.core.api.models.parameter_option.ParameterOption(
                                            name = '0', 
                                            value = '0', )
                                        ], )
                                ], 
                            workflow_template = onepanel.core.api.models.workflow_template.WorkflowTemplate(
                                created_at = '0', 
                                modified_at = '0', 
                                uid = '0', 
                                name = '0', 
                                version = '0', 
                                versions = '0', 
                                manifest = '0', 
                                is_latest = True, 
                                is_archived = True, 
                                labels = [
                                    onepanel.core.api.models.key_value.KeyValue(
                                        key = '0', 
                                        value = '0', )
                                    ], 
                                stats = onepanel.core.api.models.workflow_execution_statistic_report.WorkflowExecutionStatisticReport(
                                    total = 56, 
                                    last_executed = '0', 
                                    running = 56, 
                                    completed = 56, 
                                    failed = 56, 
                                    terminated = 56, ), 
                                cron_stats = onepanel.core.api.models.cron_workflow_statistics_report.CronWorkflowStatisticsReport(
                                    total = 56, ), ), 
                            labels = [
                                onepanel.core.api.models.key_value.KeyValue(
                                    key = '0', 
                                    value = '0', )
                                ], ), 
                        labels = [
                            onepanel.core.api.models.key_value.KeyValue(
                                key = '0', 
                                value = '0', )
                            ], 
                        namespace = '0', )
                    ], 
                page = 56, 
                pages = 56, 
                total_count = 56
            )
        else :
            return ListCronWorkflowsResponse(
        )

    def testListCronWorkflowsResponse(self):
        """Test ListCronWorkflowsResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Onepanel

    Onepanel API  # noqa: E501

    The version of the OpenAPI document: 0.12.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from onepanel.core.api.models.add_secret_key_value_response import AddSecretKeyValueResponse
from onepanel.core.api.models.archive_workflow_template_response import ArchiveWorkflowTemplateResponse
from onepanel.core.api.models.artifact_response import ArtifactResponse
from onepanel.core.api.models.create_workflow_execution_body import CreateWorkflowExecutionBody
from onepanel.core.api.models.create_workspace_body import CreateWorkspaceBody
from onepanel.core.api.models.cron_workflow import CronWorkflow
from onepanel.core.api.models.cron_workflow_statistics_report import CronWorkflowStatisticsReport
from onepanel.core.api.models.delete_secret_key_response import DeleteSecretKeyResponse
from onepanel.core.api.models.delete_secret_response import DeleteSecretResponse
from onepanel.core.api.models.file import File
from onepanel.core.api.models.get_config_response import GetConfigResponse
from onepanel.core.api.models.get_labels_response import GetLabelsResponse
from onepanel.core.api.models.get_workflow_execution_metrics_response import GetWorkflowExecutionMetricsResponse
from onepanel.core.api.models.google_protobuf_any import GoogleProtobufAny
from onepanel.core.api.models.grpc_gateway_runtime_error import GrpcGatewayRuntimeError
from onepanel.core.api.models.grpc_gateway_runtime_stream_error import GrpcGatewayRuntimeStreamError
from onepanel.core.api.models.is_authorized import IsAuthorized
from onepanel.core.api.models.is_authorized_response import IsAuthorizedResponse
from onepanel.core.api.models.is_valid_token_response import IsValidTokenResponse
from onepanel.core.api.models.key_value import KeyValue
from onepanel.core.api.models.labels import Labels
from onepanel.core.api.models.list_cron_workflows_response import ListCronWorkflowsResponse
from onepanel.core.api.models.list_files_response import ListFilesResponse
from onepanel.core.api.models.list_namespaces_response import ListNamespacesResponse
from onepanel.core.api.models.list_secrets_response import ListSecretsResponse
from onepanel.core.api.models.list_services_response import ListServicesResponse
from onepanel.core.api.models.list_workflow_executions_response import ListWorkflowExecutionsResponse
from onepanel.core.api.models.list_workflow_template_versions_response import ListWorkflowTemplateVersionsResponse
from onepanel.core.api.models.list_workflow_templates_response import ListWorkflowTemplatesResponse
from onepanel.core.api.models.list_workspace_response import ListWorkspaceResponse
from onepanel.core.api.models.list_workspace_template_versions_response import ListWorkspaceTemplateVersionsResponse
from onepanel.core.api.models.list_workspace_templates_response import ListWorkspaceTemplatesResponse
from onepanel.core.api.models.log_entry import LogEntry
from onepanel.core.api.models.metric import Metric
from onepanel.core.api.models.namespace import Namespace
from onepanel.core.api.models.node_pool import NodePool
from onepanel.core.api.models.node_pool_option import NodePoolOption
from onepanel.core.api.models.parameter import Parameter
from onepanel.core.api.models.parameter_option import ParameterOption
from onepanel.core.api.models.secret import Secret
from onepanel.core.api.models.secret_exists_response import SecretExistsResponse
from onepanel.core.api.models.service import Service
from onepanel.core.api.models.statistics import Statistics
from onepanel.core.api.models.stream_result_of_log_entry import StreamResultOfLogEntry
from onepanel.core.api.models.stream_result_of_workflow_execution import StreamResultOfWorkflowExecution
from onepanel.core.api.models.token_wrapper import TokenWrapper
from onepanel.core.api.models.update_secret_key_value_response import UpdateSecretKeyValueResponse
from onepanel.core.api.models.update_workspace_body import UpdateWorkspaceBody
from onepanel.core.api.models.workflow_execution import WorkflowExecution
from onepanel.core.api.models.workflow_execution_metadata import WorkflowExecutionMetadata
from onepanel.core.api.models.workflow_execution_statistic_report import WorkflowExecutionStatisticReport
from onepanel.core.api.models.workflow_execution_status import WorkflowExecutionStatus
from onepanel.core.api.models.workflow_template import WorkflowTemplate
from onepanel.core.api.models.workspace import Workspace
from onepanel.core.api.models.workspace_status import WorkspaceStatus
from onepanel.core.api.models.workspace_template import WorkspaceTemplate



# coding: utf-8

# flake8: noqa

"""
    workflow.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from core.api.api.namespace_service_api import NamespaceServiceApi
from core.api.api.secret_service_api import SecretServiceApi
from core.api.api.workflow_service_api import WorkflowServiceApi

# import ApiClient
from core.api.api_client import ApiClient
from core.api.configuration import Configuration
from core.api.exceptions import OpenApiException
from core.api.exceptions import ApiTypeError
from core.api.exceptions import ApiValueError
from core.api.exceptions import ApiKeyError
from core.api.exceptions import ApiException
# import models into sdk package
from core.api.models.add_secret_key_value_response import AddSecretKeyValueResponse
from core.api.models.archive_workflow_template_response import ArchiveWorkflowTemplateResponse
from core.api.models.delete_secret_key_response import DeleteSecretKeyResponse
from core.api.models.delete_secret_response import DeleteSecretResponse
from core.api.models.get_workflow_execution_metrics_response import GetWorkflowExecutionMetricsResponse
from core.api.models.google_protobuf_any import GoogleProtobufAny
from core.api.models.grpc_gateway_runtime_error import GrpcGatewayRuntimeError
from core.api.models.grpc_gateway_runtime_stream_error import GrpcGatewayRuntimeStreamError
from core.api.models.list_namespaces_response import ListNamespacesResponse
from core.api.models.list_secrets_response import ListSecretsResponse
from core.api.models.list_workflow_executions_response import ListWorkflowExecutionsResponse
from core.api.models.list_workflow_template_versions_response import ListWorkflowTemplateVersionsResponse
from core.api.models.list_workflow_templates_response import ListWorkflowTemplatesResponse
from core.api.models.log_entry import LogEntry
from core.api.models.metric import Metric
from core.api.models.namespace import Namespace
from core.api.models.secret import Secret
from core.api.models.secret_exists_response import SecretExistsResponse
from core.api.models.stream_result_of_log_entry import StreamResultOfLogEntry
from core.api.models.stream_result_of_workflow_execution import StreamResultOfWorkflowExecution
from core.api.models.update_secret_key_value_response import UpdateSecretKeyValueResponse
from core.api.models.workflow_execution import WorkflowExecution
from core.api.models.workflow_execution_parameter import WorkflowExecutionParameter
from core.api.models.workflow_template import WorkflowTemplate




# coding: utf-8

"""
    Onepanel

    Onepanel API  # noqa: E501

    The version of the OpenAPI document: 0.12.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onepanel.core.api
from onepanel.core.api.models.stream_result_of_log_entry import StreamResultOfLogEntry  # noqa: E501
from onepanel.core.api.rest import ApiException

class TestStreamResultOfLogEntry(unittest.TestCase):
    """StreamResultOfLogEntry unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test StreamResultOfLogEntry
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = onepanel.core.api.models.stream_result_of_log_entry.StreamResultOfLogEntry()  # noqa: E501
        if include_optional :
            return StreamResultOfLogEntry(
                result = onepanel.core.api.models.log_entry.LogEntry(
                    timestamp = '0', 
                    content = '0', ), 
                error = onepanel.core.api.models.grpc/gateway/runtime/stream_error.grpc.gateway.runtime.StreamError(
                    grpc_code = 56, 
                    http_code = 56, 
                    message = '0', 
                    http_status = '0', 
                    details = [
                        onepanel.core.api.models.google/protobuf/any.google.protobuf.Any(
                            type_url = '0', 
                            value = 'YQ==', )
                        ], )
            )
        else :
            return StreamResultOfLogEntry(
        )

    def testStreamResultOfLogEntry(self):
        """Test StreamResultOfLogEntry"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Onepanel

    Onepanel API  # noqa: E501

    The version of the OpenAPI document: 0.12.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from onepanel.core.api.configuration import Configuration


class IsAuthorized(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'namespace': 'str',
        'verb': 'str',
        'group': 'str',
        'resource': 'str',
        'resource_name': 'str'
    }

    attribute_map = {
        'namespace': 'namespace',
        'verb': 'verb',
        'group': 'group',
        'resource': 'resource',
        'resource_name': 'resourceName'
    }

    def __init__(self, namespace=None, verb=None, group=None, resource=None, resource_name=None, local_vars_configuration=None):  # noqa: E501
        """IsAuthorized - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._namespace = None
        self._verb = None
        self._group = None
        self._resource = None
        self._resource_name = None
        self.discriminator = None

        if namespace is not None:
            self.namespace = namespace
        if verb is not None:
            self.verb = verb
        if group is not None:
            self.group = group
        if resource is not None:
            self.resource = resource
        if resource_name is not None:
            self.resource_name = resource_name

    @property
    def namespace(self):
        """Gets the namespace of this IsAuthorized.  # noqa: E501


        :return: The namespace of this IsAuthorized.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this IsAuthorized.


        :param namespace: The namespace of this IsAuthorized.  # noqa: E501
        :type namespace: str
        """

        self._namespace = namespace

    @property
    def verb(self):
        """Gets the verb of this IsAuthorized.  # noqa: E501


        :return: The verb of this IsAuthorized.  # noqa: E501
        :rtype: str
        """
        return self._verb

    @verb.setter
    def verb(self, verb):
        """Sets the verb of this IsAuthorized.


        :param verb: The verb of this IsAuthorized.  # noqa: E501
        :type verb: str
        """

        self._verb = verb

    @property
    def group(self):
        """Gets the group of this IsAuthorized.  # noqa: E501


        :return: The group of this IsAuthorized.  # noqa: E501
        :rtype: str
        """
        return self._group

    @group.setter
    def group(self, group):
        """Sets the group of this IsAuthorized.


        :param group: The group of this IsAuthorized.  # noqa: E501
        :type group: str
        """

        self._group = group

    @property
    def resource(self):
        """Gets the resource of this IsAuthorized.  # noqa: E501


        :return: The resource of this IsAuthorized.  # noqa: E501
        :rtype: str
        """
        return self._resource

    @resource.setter
    def resource(self, resource):
        """Sets the resource of this IsAuthorized.


        :param resource: The resource of this IsAuthorized.  # noqa: E501
        :type resource: str
        """

        self._resource = resource

    @property
    def resource_name(self):
        """Gets the resource_name of this IsAuthorized.  # noqa: E501


        :return: The resource_name of this IsAuthorized.  # noqa: E501
        :rtype: str
        """
        return self._resource_name

    @resource_name.setter
    def resource_name(self, resource_name):
        """Sets the resource_name of this IsAuthorized.


        :param resource_name: The resource_name of this IsAuthorized.  # noqa: E501
        :type resource_name: str
        """

        self._resource_name = resource_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IsAuthorized):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, IsAuthorized):
            return True

        return self.to_dict() != other.to_dict()
